%% Figure 1
load DataForFigure1.mat
figure(1);
Percentile = 10;
Bandwidth = 1;
bws = [[]]
% Looping Animal_ID from 1 to 3, i.e., from marmoset to bat to humans.
for Animal_ID = 1:3
    
    % Define a variable determining the ages available
    Discrete_age_range{Animal_ID} = unique(Postnatal_day_per_call{Animal_ID});
    % Get variable estimating the minimum immature age and maximum mature
    % age through the percentile
    Extreme_age_limits{Animal_ID} = [prctile(Discrete_age_range{Animal_ID},Percentile),prctile(Discrete_age_range{Animal_ID},100-Percentile)];    
    Age_limit = Extreme_age_limits{Animal_ID};
    
    % Establish a range for the PAC
    PAC_range = linspace(-5,5,500);
    % Define a variable determining the subject IDs available
    Subject_ID_range = unique(Subject_ID_per_call{Animal_ID});

    % These variables will contain the distributions for each subject
    % of the PAC distribution in the immature and in the mature period
    PAC_immature_per_subject = NaN(max(Subject_ID_range),length(PAC_range));
    PAC_mature_per_subject = NaN(max(Subject_ID_range),length(PAC_range));

    % Now  this is looping over each individual in the dataset
    for Subject_ID = Subject_ID_range

        % Find indices of the vocalizations for this specific animal
        Indices_subject = Subject_ID_per_call{Animal_ID} == Subject_ID;

        % Find indices immature and mature periods
        Indices_Immature = Postnatal_day_per_call{Animal_ID} < Age_limit(1);
        Indices_Mature = Postnatal_day_per_call{Animal_ID} > Age_limit(2);    
        
        % Find the appropriate indices
        Indices_Subject_Immature = logical(Indices_subject.*Indices_Immature);
        Indices_Subject_Mature = logical(Indices_subject.*Indices_Mature);

        % Filter for the appropriate PACs
        PACs_Immature = PAC_per_call{Animal_ID}(Indices_Subject_Immature);
        PACs_Mature = PAC_per_call{Animal_ID}(Indices_Subject_Mature);

        % Check if not empty
        if ~isempty(PACs_Immature)
            [PAC_distribution_immature] = ksdensity(PACs_Immature, PAC_range,'bandwidth',Bandwidth);
            PAC_immature_per_subject(Subject_ID, :) = PAC_distribution_immature;
        end

        if ~isempty(PACs_Mature)
            [PAC_distribution_mature] = ksdensity(PACs_Mature, PAC_range,'bandwidth',Bandwidth);
            PAC_mature_per_subject(Subject_ID, :) = PAC_distribution_mature;
        end

    end

    % Average the distributions
    Distribution_immature = nanmean(PAC_immature_per_subject,1);
    Distribution_mature = nanmean(PAC_mature_per_subject,1);

    % Plot
    subplot(3,1,Animal_ID); plot(PAC_range, Distribution_immature);
    xlim([-5,5]); ylim([0,0.35]); hold on;
    subplot(3,1,Animal_ID); plot(PAC_range, Distribution_mature);
    xlim([-5,5]); ylim([0,0.35]); hold off;
    ylabel('Prob. distribution')
    
    % Two-sample Kolmogorov-Smirnov test    
    [h,p] = kstest2(PAC_per_call{Animal_ID}(Indices_Immature), PAC_per_call{Animal_ID}(Indices_Mature));
    title(['p-val = ',num2str(p)]);
    
    
end
xlabel('Principal Acoustic Component (PAC)')

set(gcf, 'Units','normalized','Position',[0 0.1 0.2 0.8])
clear
%% Figure 2
load DataForFigure2.mat
figure(2);

% Panel: Model on sample individual
for Animal_ID = 1:3
    subplot(4,3,Animal_ID)
    plot(Age_range_continuous_individual{Animal_ID}, Optimized_models_individual{Animal_ID},'LineWidth',2); hold on;
    plot(Age_range_discrete_individual{Animal_ID}, Typical_PAC_per_day_individual{Animal_ID},'k.');
    ylabel('PAC (individual)');
    xlabel('PND'); hold off
end

% Panel: Model on population
for Animal_ID = 1:3
    subplot(4,3,3+Animal_ID)
    plot(Age_range_continuous{Animal_ID}, Optimized_models{Animal_ID},'LineWidth',2); hold on;
    plot(Age_range_discrete{Animal_ID}, Typical_PAC_per_day{Animal_ID},'k.');
    ylabel('PAC (population)');
    xlabel('PND'); hold off
end

% Panel: R2 comparison
for Animal_ID = 1:3
    subplot(4,3,6+Animal_ID)
    plot([0,Optimized_R2{Animal_ID}(1)],[3,3],'.-'); hold on;
    plot([0,Optimized_R2{Animal_ID}(2)],[2,2],'.-'); hold on;
    plot([0,Optimized_R2{Animal_ID}(3)],[1,1],'.-');
    ylim([0.8,3.2]);
    ylabel('Model');
    xlabel('R2'); hold off
end

% Panel: Transition day comparison
bandwidths = [0.85, 3.1, 30];
for Animal_ID = 1:3
    subplot(4,3,9+Animal_ID)
    
    % Probability density of the model transition day bootstrapped
    [f,xi]=ksdensity(Transition_day_bootstrapped{Animal_ID, 2}, Age_range_continuous{Animal_ID}, 'bandwidth', bandwidths(Animal_ID)); % ksdensity balance transition
    plot(xi,f,'r'); hold on;
    max_y = max(f);
    plot([Transition_days{Animal_ID,2},Transition_days{Animal_ID,2}],[0,max_y],'r'); hold on;

    % Confidence interval of the experimental transition day bootstrapped
    plot([prctile(Transition_day_bootstrapped{Animal_ID,1},2.5), prctile(Transition_day_bootstrapped{Animal_ID,1},97.5)], [max_y/2,max_y/2], 'k.-');
    hold on; 
    plot(Transition_days{Animal_ID,1},max_y/2,'k.'); hold on;

    % Adjust xlim and labels
    xlim([Age_range_discrete{Animal_ID}(1), Age_range_discrete{Animal_ID}(end)]);
    ylabel('Prob. density');
    xlabel('PND'); hold off
end

set(gcf, 'Units','normalized','Position',[0.2 0.1 0.4 0.8])
clear
%% Figure 3
load DataForFigure3.mat
figure(3);

Postnatal_day = [];
Information_transmission = [];

% Aggregate the variables of interest into two array, one for day and one
% for information 
for i = 1:length(Postnatal_day_Granger)
    l = length(Postnatal_day_Granger{i});
    for j = 1:l
        Postnatal_day = [Postnatal_day Postnatal_day_Granger{i}(j)];

        Granger_causality_analysis = -Difference_interaction_strength_Granger{i}{j};
        Information_transmission = [Information_transmission (Granger_causality_analysis(2,1))];        
    end
end

mins = linspace(0,60);
maxs = linspace(0,60);

% Bootstrap of the csaps
param = 0.000001;
xx = linspace(0,60);
yy = csaps(Postnatal_day,Information_transmission,param,xx);
bootyy = boot_csaps(Postnatal_day,Information_transmission,param,xx,2000);

% Standard deviation from bootstrap
stdbootyy = std(bootyy);

subplot(2,1,1)
plot(xx,yy,'k'); hold on;
plot(xx,yy+1.96*stdbootyy,'g'); hold on;
plot(xx,yy-1.96*stdbootyy,'g'); hold off;
ylabel('Information transmission')
xlabel('Postnatal day')

subplot(2,1,2)
ymin = -2.5; ymax = 3;
% Typical PAC per day for high contingency data
plot(Postnatal_day_contingency{1}, Typical_PAC_per_day_contingency{1},'g.'); hold on;
% Transition day from sigmoid
plot([Transition_day{1}, Transition_day{1}],[ymin, ymax],'color','g','LineWidth',2); hold on;
% Bootstrap confidence interval
x = [prctile(Transition_day_bootstrapped{1}, 2.5),prctile(Transition_day_bootstrapped{1}, 97.5)];
fill([x flip(x)],[[ymax, ymax] [ymin,ymin]],'g','LineStyle','none')
alpha(0.25)    

% Typical PAC per day for low contingency data
plot(Postnatal_day_contingency{2}, Typical_PAC_per_day_contingency{2},'b.'); hold on;
% Transition day from sigmoid
plot([Transition_day{2}, Transition_day{2}],[ymin, ymax],'color','b','LineWidth',2); hold on;
% Bootstrap confidence interval
x = [prctile(Transition_day_bootstrapped{2}, 2.5),prctile(Transition_day_bootstrapped{2}, 97.5)];
fill([x flip(x)],[[ymax, ymax] [ymin,ymin]],'b','LineStyle','none')
alpha(0.25)    

ylabel('PAC')
xlabel('Postnatal day')
xlim([0,60]);
ylim([ymin, ymax]);

set(gcf, 'Units','normalized','Position',[0.6 0.1 0.2 0.8])

figure(9);
plot(Postnatal_day,Information_transmission,'.'); hold on;
plot(xx,yy,'k'); hold on;
plot(xx,yy+1.96*stdbootyy,'g'); hold on;
plot(xx,yy-1.96*stdbootyy,'g'); hold off;
ylabel('Information transmission')
xlabel('Postnatal day')

clear
%% Figure 4
load DataForFigure1.mat
load DataForFigure4.mat
figure(4);

Ages = Postnatal_day_per_call{1};
IDs = Subject_ID_per_call{1};
n_ages = length(unique(Ages));
n_IDs = length(unique(IDs));

Calls_per_session_antiphonal = [];
Postnatal_day_antiphonal = [];

for subj = 1:n_IDs    
    for day = 1:n_ages
        if(sum((IDs == subj).*(Ages == day)) > 0)
            Calls_per_session_antiphonal = [Calls_per_session_antiphonal sum((IDs == subj).*(Ages == day))];
            Postnatal_day_antiphonal = [Postnatal_day_antiphonal day];
        end
    end
end

param = 0.00001;

xx = linspace(1,60);
yy = csaps(Postnatal_day_antiphonal,Calls_per_session_antiphonal,param,xx);
bootyy = boot_csaps(Postnatal_day_antiphonal,Calls_per_session_antiphonal,param,xx,1000);
% Standard deviation from bootstrap
stdbootyy = std(bootyy);
% plot(Postnatal_day_antiphonal, Calls_per_session_antiphonal, '.'); hold on;
subplot(2,1,1)
plot(xx,yy,'k'); hold on;
plot(xx,yy+1.96*stdbootyy,'g'); hold on;
plot(xx,yy-1.96*stdbootyy,'g'); hold off;
ylabel('Number of calls per session')
xlabel('Postnatal day')
xlim([0,61])

subplot(2,1,2)
ymin = -2.5; ymax = 2.5;
% Typical PAC per day for regular air data
plot(Postnatal_day_heliox{1}, Typical_PAC_per_day_heliox{1},'k.'); hold on;
% Transition day from sigmoid
plot([Transition_day_heliox{1}, Transition_day_heliox{1}],[ymin, ymax],'color','k','LineWidth',2); hold on;
% Bootstrap confidence interval
x = [prctile(Transition_day_heliox_bootstrapped{1}, 2.5),prctile(Transition_day_heliox_bootstrapped{1}, 97.5)];
fill([x flip(x)],[[ymax, ymax] [ymin,ymin]],'k','LineStyle','none')
alpha(0.25)    

% Typical PAC per day for heliox data
plot(Postnatal_day_heliox{2}, Typical_PAC_per_day_heliox{2},'r.'); hold on;
% Transition day from sigmoid
plot([Transition_day_heliox{2}, Transition_day_heliox{2}],[ymin, ymax],'color','r','LineWidth',2); hold on;
% Bootstrap confidence interval
x = [prctile(Transition_day_heliox_bootstrapped{2}, 2.5),prctile(Transition_day_heliox_bootstrapped{2}, 97.5)];
fill([x flip(x)],[[ymax, ymax] [ymin,ymin]],'r','LineStyle','none')
alpha(0.25)    

ylabel('PAC')
xlabel('Postnatal day')
xlim([0,70]);
ylim([ymin, ymax]);

set(gcf, 'Units','normalized','Position',[0.8 0.1 0.2 0.8])

% figure(10);
% plot(Postnatal_day_HR,EnergyEff,'.'); hold on;
% semilogy(xx,yy,'k'); hold on;
% semilogy(xx,yy-1.96*stdbootyy,'r'); hold on;
% semilogy(xx,yy+1.96*stdbootyy,'r'); hold off;
% ylim([0.1, 5])
% xlim([0,61])
% ylabel('Energy Efficiency')
% xlabel('Postnatal day')

clear
